from django.db import connections
from django.db.models import Manager


class TaskManager(Manager):
    def parents(self, task):
        """
        List all tasks that a task depends on, directly or not.

        When using a PostgreSQL database, this will use a recursive query.
        This falls back to a recursive generator on other databases.
        """
        if connections[self.db].vendor == "postgresql":
            return self.raw(
                """
                with recursive parents(id) as (
                    select to_task_id
                        from ponos_task_parents j
                        where j.from_task_id = %s
                    union all
                        select j.to_task_id
                        from ponos_task_parents as j, parents
                        where j.from_task_id = parents.id
                )
                select distinct * from parents
                """,
                [task.id],
            )
        else:

            def _parents_python(task):
                yield from task.parents.all()
                for parent in task.parents.all():
                    yield from _parents_python(parent)

            return _parents_python(task)
