# Generated by Django 2.2.12 on 2020-06-05 08:53

from django.db import migrations, models

from arkindex.ponos.recipe import parse_recipe

try:
    import jsonfield

    json_field_cls = jsonfield.JSONField
except ImportError:
    json_field_cls = models.JSONField


def parse_workflows_recipe(apps, schema_editor):
    """
    Retrieve and parse recipe for reach workflow to populate new attributes
    (image, command, env) on its associated tasks
    """

    db_alias = schema_editor.connection.alias
    Workflow = apps.get_model("ponos", "Workflow")
    for workflow in Workflow.objects.using(db_alias).all():
        _, recipes = parse_recipe(workflow.recipe)
        for slug, task_recipe in recipes.items():
            for task in workflow.tasks.filter(slug=slug):
                task.image = task_recipe.image
                if task_recipe.command:
                    task.command = task_recipe.command
                if task_recipe.environment:
                    task.env = task_recipe.environment
                task.save()


class Migration(migrations.Migration):

    dependencies = [
        ("ponos", "0013_artifact"),
    ]

    operations = [
        migrations.AddField(
            model_name="task",
            name="command",
            field=models.TextField(null=True),
        ),
        migrations.AddField(
            model_name="task",
            name="env",
            field=json_field_cls(null=True),
        ),
        migrations.AddField(
            model_name="task",
            name="image",
            field=models.CharField(null=True, max_length=250),
        ),
        migrations.RunPython(
            parse_workflows_recipe,
            reverse_code=migrations.RunPython.noop,
        ),
        migrations.AlterField(
            model_name="task",
            name="image",
            field=models.CharField(max_length=250),
        ),
    ]
