from rest_framework.permissions import SAFE_METHODS, IsAuthenticated

from arkindex.ponos.models import Task


class IsAgent(IsAuthenticated):
    """
    Only allow Ponos agents and admins
    """

    def has_permission(self, request, view) -> bool:
        if (
            request.user.is_staff
            or hasattr(request.user, "is_agent")
            and request.user.is_agent
        ):
            return super().has_permission(request, view)
        return False


class IsAgentOrReadOnly(IsAgent):
    """
    Restricts write access to Ponos agents and admins
    """

    def has_permission(self, request, view) -> bool:
        return request.method in SAFE_METHODS or super().has_permission(request, view)


class IsAssignedAgentOrReadOnly(IsAgentOrReadOnly):
    """
    Restricts write access to Ponos agents and admins,
    and restricts write access on tasks to admins and agents assigned to them.
    """

    def has_object_permission(self, request, view, obj) -> bool:
        if (
            isinstance(obj, Task)
            and not request.user.is_staff
            and not request.user == obj.agent
        ):
            return request.method in SAFE_METHODS
        return super().has_object_permission(request, view, obj)
