from django.test import TestCase

from arkindex.ponos.admin import ClearTextSecretForm, SecretAdmin
from arkindex.ponos.models import Secret, encrypt


class TestAdmin(TestCase):
    @classmethod
    def setUpTestData(cls):
        cls.nonce = b"1337" * 4
        cls.encrypted_content = encrypt(cls.nonce, "Shhhh")
        cls.secret = Secret.objects.create(
            name="important_secret", nonce=cls.nonce, content=cls.encrypted_content
        )

    def test_admin_read_secret(self):
        """
        Admin form display the decrypted content of the stored secrets
        """
        self.assertEqual(self.secret.content, b"\xa3\xda\x9b\x91#")
        form = ClearTextSecretForm(instance=self.secret)
        self.assertEqual(form.initial.get("content"), "Shhhh")

    def test_admin_updates_secret(self):
        secret_admin = SecretAdmin(model=Secret, admin_site=None)
        form = ClearTextSecretForm(
            data={"id": self.secret.id, "name": self.secret.name, "content": "Ah"},
            instance=self.secret,
        )
        self.assertEqual(self.secret.content, b"\xa3\xda\x9b\x91#")
        secret_admin.save_form(request=None, form=form, change=True)
        self.assertEqual(self.secret.content, b"\xb1\xda")
        self.assertEqual(b"\xb1\xda", encrypt(self.secret.nonce, "Ah"))
