from textwrap import dedent

from django.test import TestCase

from arkindex.ponos.recipe import parse_recipe

# List of (broken recipe, expected AssertionError message) tuples
ERROR_CASES = [
    ("[]", "Recipe should be a dict"),
    ("tasks: {}", "No tasks"),
    ("tasks: [{image: lol}]", "Tasks should be a dict"),
    ("tasks: {a: {}, '': {}}", "Tasks should have non-blank slugs"),
    ("tasks: {a: []}", "Task should be a dict"),
    ("tasks: {a: {}}", "Missing image"),
    (
        """
    tasks:
      lol:
        image: blah
        artifact: 42
    """,
        "Task artifact should be a string",
    ),
    (
        """
    tasks:
      lol:
        image: blah
        artifact: philosophers_stone
    """,
        "Task artifact should be a valid UUID string",
    ),
]


class TestRecipe(TestCase):
    def test_recipe_errors(self):
        for recipe, expected_message in ERROR_CASES:
            with self.subTest(recipe=recipe), self.assertRaisesMessage(
                AssertionError, expected_message
            ):
                parse_recipe(dedent(recipe))
