import uuid
from unittest import TestCase
from unittest.mock import patch

from arkindex.ponos import get_ponos_run, get_ponos_task_id, is_ponos_task


class TestUtil(TestCase):
    def test_is_ponos_task(self):
        with patch.dict("ponos.helpers.os.environ", clear=True):
            self.assertFalse(is_ponos_task())

        with patch.dict(
            "ponos.helpers.os.environ", PONOS_TASK=str(uuid.uuid4()), clear=True
        ):
            self.assertTrue(is_ponos_task())

    def test_get_ponos_task_id(self):
        with patch.dict("ponos.helpers.os.environ", clear=True):
            self.assertIsNone(get_ponos_task_id())

        task_id = uuid.uuid4()
        with patch.dict(
            "ponos.helpers.os.environ", PONOS_TASK=str(task_id), clear=True
        ):
            self.assertEqual(get_ponos_task_id(), task_id)

    def test_get_ponos_run(self):
        with patch.dict("ponos.helpers.os.environ", clear=True):
            self.assertIsNone(get_ponos_run())

        with patch.dict("ponos.helpers.os.environ", PONOS_RUN="42", clear=True):
            self.assertEqual(get_ponos_run(), 42)
