from django.urls import path

from arkindex.ponos.api import (
    AgentActions,
    AgentDetails,
    AgentRegister,
    AgentsState,
    AgentTokenRefresh,
    FarmList,
    PublicKeyEndpoint,
    SecretDetails,
    TaskArtifactDownload,
    TaskArtifacts,
    TaskCreate,
    TaskDefinition,
    TaskDetailsFromAgent,
    TaskUpdate,
    WorkflowDetails,
)

app_name = "ponos"
urlpatterns = [
    path("v1/workflow/<uuid:pk>/", WorkflowDetails.as_view(), name="workflow-details"),
    path("v1/task/", TaskCreate.as_view(), name="task-create"),
    path("v1/task/<uuid:pk>/", TaskUpdate.as_view(), name="task-update"),
    path(
        "v1/task/<uuid:pk>/from-agent/",
        TaskDetailsFromAgent.as_view(),
        name="task-details",
    ),
    path(
        "v1/task/<uuid:pk>/definition/",
        TaskDefinition.as_view(),
        name="task-definition",
    ),
    path(
        "v1/task/<uuid:pk>/artifacts/", TaskArtifacts.as_view(), name="task-artifacts"
    ),
    path(
        "v1/task/<uuid:pk>/artifact/<path:path>",
        TaskArtifactDownload.as_view(),
        name="task-artifact-download",
    ),
    path("v1/agent/", AgentRegister.as_view(), name="agent-register"),
    path("v1/agent/<uuid:pk>/", AgentDetails.as_view(), name="agent-details"),
    path("v1/agent/refresh/", AgentTokenRefresh.as_view(), name="agent-token-refresh"),
    path("v1/agent/actions/", AgentActions.as_view(), name="agent-actions"),
    path("v1/agents/", AgentsState.as_view(), name="agents-state"),
    path("v1/public-key/", PublicKeyEndpoint.as_view(), name="public-key"),
    path("v1/secret/<path:name>", SecretDetails.as_view(), name="secret-details"),
    path("v1/farms/", FarmList.as_view(), name="farm-list"),
]
