# Generated by Django 4.0.2 on 2022-06-13 12:40

from django.db import migrations, models
from django.db.models.query import Prefetch


def generate_worker_run_summaries(apps, schema_editor):
    WorkerRun = apps.get_model('process', 'WorkerRun')
    GitRef = apps.get_model('process', 'GitRef')
    runs = WorkerRun.objects.select_related(
        'version__worker',
        'version__revision',
        'model_version__model',
        'configuration'
    ).only(
        # Required to make joins and for the bulk update
        'id',
        'version_id',
        'version__worker__name',
        # Required for the prefetch_related. Using `revision_id` instead of `revision__id` causes Django to select the entire revision anyway
        'version__revision__id',
        'model_version_id',
        'model_version__model__name',
        'configuration__name'
    ).prefetch_related(
        Prefetch(
            'version__revision__refs',
            # revision_id is required to make the link between refs and revisions
            queryset=GitRef.objects.only('revision_id', 'name')
        )
    )

    for run in runs:
        summary_text = f"Worker {run.version.worker.name} @ "
        git_ref_names = run.version.revision.refs.values_list('name', flat=True)
        if len(git_ref_names) > 0:
            summary_text += ", ".join(git_ref_names)
        else:
            summary_text += str(run.version.id)[0:6]

        if run.model_version:
            summary_text += f" with model {run.model_version.model.name} @ {str(run.model_version.id)[0:6]}"

        if run.configuration:
            summary_text += f" using configuration '{run.configuration.name}'"

        run.summary = summary_text
    WorkerRun.objects.bulk_update(runs, ['summary'])


class Migration(migrations.Migration):

    dependencies = [
        ('process', '0049_dataimport_s3'),
    ]

    operations = [
        migrations.AddField(
            model_name='workerrun',
            name='summary',
            field=models.TextField(null=True),
        ),
        migrations.RunPython(
            generate_worker_run_summaries,
            reverse_code=migrations.RunPython.noop
        ),
        migrations.AlterField(
            model_name='workerrun',
            name='summary',
            field=models.TextField(),
        ),
    ]
