from django.contrib import admin
from enumfields.admin import EnumFieldListFilter

from arkindex.training.models import MetricKey, MetricValue, Model, ModelVersion


class ModelAdmin(admin.ModelAdmin):
    list_display = ('name', 'created', )
    search_fields = ('name', 'description', )
    fields = ('name', 'description', 'public', 'compatible_workers')


class ModelVersionAdmin(admin.ModelAdmin):
    list_display = ('id', 'model', 'tag', 'size', 'state')
    list_filter = ('model__name', ('state', EnumFieldListFilter), )
    fields = ('model', 'parent', 'description', 'state', 'tag', 'hash', 'archive_hash', 'size', 'configuration',)
    readonly_fields = ('hash', 'archive_hash', 'size', )


class MetricValueInline(admin.StackedInline):
    model = MetricValue
    readonly_fields = ('value', 'step')


class MetricKeyAdmin(admin.ModelAdmin):
    list_display = ('name', 'model_version')
    fields = ('name', 'mode', 'model_version')
    list_filter = ('model_version__model',)
    inlines = [MetricValueInline, ]


admin.site.register(Model, ModelAdmin)
admin.site.register(ModelVersion, ModelVersionAdmin)
admin.site.register(MetricKey, MetricKeyAdmin)
